NaMaster: Globals

NaMaster

- Main Page
- Data Structures
- Files

- File List
- Globals

- All
- Functions
- Typedefs
- Macros

- c
- d
- e
- f
- h
- i
- m
- n
- r

### - c -

- cov_get_coupling_pair_index() : utils.h

### - d -

- dftw_free() : utils.h
- dftw_malloc() : utils.h
- drc3jj() : utils.h

### - e -

- end_rng() : utils.h

### - f -

- fs_alm2cl() : utils.h
- fs_alm2map() : utils.h
- fs_alter_alm() : utils.h
- fs_anafast() : utils.h
- fs_generate_beam_window() : utils.h
- fs_map2alm() : utils.h
- fs_map_dot() : utils.h
- fs_map_product() : utils.h
- fs_mapcpy() : utils.h
- fs_read_flat_map() : utils.h
- fs_synalm() : utils.h
- fs_zero_alm() : utils.h

### - h -

- he_alm2cl() : utils.h
- he_alm2map() : utils.h
- he_alter_alm() : utils.h
- he_anafast() : utils.h
- he_ang2pix() : utils.h
- he_generate_beam_window() : utils.h
- he_get_file_params() : utils.h
- he_get_largest_possible_lmax() : utils.h
- he_get_lmax() : utils.h
- he_get_pix_area() : utils.h
- he_in_ring() : utils.h
- he_indexlm() : utils.h
- he_map2alm() : utils.h
- he_map_dot() : utils.h
- he_map_product() : utils.h
- he_nalms() : utils.h
- he_nest2ring_inplace() : utils.h
- he_nside2npix() : utils.h
- he_pix2vec_ring() : utils.h
- he_query_disc() : utils.h
- he_query_strip() : utils.h
- he_read_map() : utils.h
- he_ring2nest_inplace() : utils.h
- he_ring_num() : utils.h
- he_synalm() : utils.h
- he_udgrade() : utils.h
- he_write_CAR_map() : utils.h
- he_write_healpix_map() : utils.h
- he_zero_alm() : utils.h

### - i -

- init_rng() : utils.h

### - m -

- moore_penrose_pinv() : utils.h
- my_calloc() : utils.h
- my_fopen() : utils.h
- my_fread() : utils.h
- my_fwrite() : utils.h
- my_linecount() : utils.h
- my_malloc() : utils.h

### - n -

- nmt_apodize_mask() : namaster.h
- nmt_apodize_mask_flat() : namaster.h
- nmt_bin_cls() : namaster.h
- nmt_bin_cls_flat() : namaster.h
- nmt_bins_constant() : namaster.h
- nmt_bins_create() : namaster.h
- nmt_bins_flat_constant() : namaster.h
- nmt_bins_flat_create() : namaster.h
- nmt_bins_flat_free() : namaster.h
- nmt_bins_flat_search_fast() : namaster.h
- nmt_bins_free() : namaster.h
- nmt_bins_read() : namaster.h
- nmt_compute_bandpower_windows() : namaster.h
- nmt_compute_coupled_cell() : namaster.h
- nmt_compute_coupled_cell_flat() : namaster.h
- nmt_compute_coupling_matrix() : namaster.h
- nmt_compute_coupling_matrix_flat() : namaster.h
- nmt_compute_deprojection_bias() : namaster.h
- nmt_compute_deprojection_bias_flat() : namaster.h
- nmt_compute_gaussian_covariance() : namaster.h
- nmt_compute_gaussian_covariance_coupled() : namaster.h
- nmt_compute_gaussian_covariance_flat() : namaster.h
- nmt_compute_master_coefficients() : namaster.h
- nmt_compute_power_spectra() : namaster.h
- nmt_compute_power_spectra_flat() : namaster.h
- nmt_compute_uncorr_noise_deprojection_bias() : namaster.h
- nmt_couple_cl_l() : namaster.h
- nmt_couple_cl_l_flat_fast() : namaster.h
- nmt_couple_cl_l_flat_quick() : namaster.h
- nmt_covar_workspace_flat_free() : namaster.h
- nmt_covar_workspace_flat_init() : namaster.h
- nmt_covar_workspace_flat_read_fits() : namaster.h
- nmt_covar_workspace_flat_write_fits() : namaster.h
- nmt_covar_workspace_free() : namaster.h
- nmt_covar_workspace_init() : namaster.h
- nmt_covar_workspace_read_fits() : namaster.h
- nmt_covar_workspace_write_fits() : namaster.h
- nmt_curvedsky_info_alloc() : namaster.h
- nmt_curvedsky_info_copy() : namaster.h
- nmt_decouple_cl_l() : namaster.h
- nmt_decouple_cl_l_flat() : namaster.h
- nmt_diff_curvedsky_info() : namaster.h
- nmt_ell_eff() : namaster.h
- nmt_ell_eff_flat() : namaster.h
- nmt_extend_CAR_map() : namaster.h
- nmt_field_alloc_sph() : namaster.h
- nmt_field_flat_alloc() : namaster.h
- nmt_field_flat_free() : namaster.h
- nmt_field_free() : namaster.h
- nmt_field_read() : namaster.h
- nmt_flatsky_info_alloc() : namaster.h
- nmt_flatsky_info_free() : namaster.h
- nmt_k_function_alloc() : namaster.h
- nmt_k_function_eval() : namaster.h
- nmt_k_function_free() : namaster.h
- nmt_master_calculator_free() : namaster.h
- nmt_purify() : namaster.h
- nmt_purify_flat() : namaster.h
- nmt_synfast_flat() : namaster.h
- nmt_synfast_sph() : namaster.h
- nmt_unbin_cls() : namaster.h
- nmt_unbin_cls_flat() : namaster.h
- nmt_update_coupling_matrix() : namaster.h
- nmt_workspace_flat_free() : namaster.h
- nmt_workspace_flat_read_fits() : namaster.h
- nmt_workspace_flat_write_fits() : namaster.h
- nmt_workspace_free() : namaster.h
- nmt_workspace_read_fits() : namaster.h
- nmt_workspace_update_beams() : namaster.h
- nmt_workspace_update_binning() : namaster.h
- nmt_workspace_write_fits() : namaster.h

### - r -

- rng_01() : utils.h
- rng_delta_gauss() : utils.h
- rng_gauss() : utils.h
- rng_poisson() : utils.h